@@ -1,24 +1,18 @@
-use super::driver::normalize_path_to_str;
 use super::XlsxError;
 use quick_xml::events::Event;
 use quick_xml::Reader;
-use std::io::Read;
-use std::{io, result};
+use std::result;
 use structs::drawing::spreadsheet::WorksheetDrawing;
+use structs::raw::RawFile;
+use structs::raw::RawRelationships;
 use structs::Worksheet;
 
-pub(crate) fn read<R: io::Read + io::Seek>(
-    arv: &mut zip::read::ZipArchive<R>,
-    target: &str,
+pub(crate) fn read(
     worksheet: &mut Worksheet,
+    drawing_file: &RawFile,
+    drawing_relationships: &RawRelationships,
 ) -> result::Result<(), XlsxError> {
-    let data = {
-        let path_str = normalize_path_to_str(&format!("xl/drawings/{}", target));
-        let mut r = io::BufReader::new(arv.by_name(path_str.as_str())?);
-        let mut buf = Vec::new();
-        r.read_to_end(&mut buf)?;
-        std::io::Cursor::new(buf)
-    };
+    let data = std::io::Cursor::new(drawing_file.get_file_data());
     let mut reader = Reader::from_reader(data);
     reader.trim_text(true);
     let mut buf = Vec::new();
@@ -31,8 +25,7 @@ pub(crate) fn read<R: io::Read + io::Seek>(
                     obj.set_attributes(
                         &mut reader,
                         e,
-                        arv,
-                        target,
+                        drawing_relationships,
                         worksheet.get_ole_objects_mut(),
                     );
                     worksheet.set_worksheet_drawing(obj);
