@@ -2,11 +2,11 @@
 use super::Glow;
 use super::OuterShadow;
 use super::SoftEdge;
-use writer::driver::*;
+use quick_xml::events::{BytesStart, Event};
 use quick_xml::Reader;
-use quick_xml::events::{Event, BytesStart};
 use quick_xml::Writer;
 use std::io::Cursor;
+use writer::driver::*;
 
 #[derive(Clone, Default, Debug)]
 pub struct EffectList {
@@ -23,7 +23,7 @@ impl EffectList {
         &mut self.glow
     }
 
-    pub fn set_glow(&mut self, value:Glow) {
+    pub fn set_glow(&mut self, value: Glow) {
         self.glow = Some(value);
     }
 
@@ -35,7 +35,7 @@ impl EffectList {
         &mut self.outer_shadow
     }
 
-    pub fn set_outer_shadow(&mut self, value:OuterShadow) {
+    pub fn set_outer_shadow(&mut self, value: OuterShadow) {
         self.outer_shadow = Some(value);
     }
 
@@ -47,14 +47,14 @@ impl EffectList {
         &mut self.soft_edge
     }
 
-    pub fn set_soft_edge(&mut self, value:SoftEdge) {
+    pub fn set_soft_edge(&mut self, value: SoftEdge) {
         self.soft_edge = Some(value);
     }
 
     pub(crate) fn set_attributes<R: std::io::BufRead>(
         &mut self,
-        reader:&mut Reader<R>,
-        _e:&BytesStart,
+        reader: &mut Reader<R>,
+        _e: &BytesStart,
         empty_flag: bool,
     ) {
         if empty_flag == true {
@@ -62,39 +62,33 @@ impl EffectList {
         }
 
         let mut buf = Vec::new();
-    
+
         loop {
             match reader.read_event(&mut buf) {
-                Ok(Event::Empty(ref e)) => {
-                    match e.name() {
-                        b"a:softEdge" => {
-                            let mut obj = SoftEdge::default();
-                            obj.set_attributes(reader, e);
-                            &mut self.set_soft_edge(obj);
-                        },
-                        _ => (),
+                Ok(Event::Empty(ref e)) => match e.name() {
+                    b"a:softEdge" => {
+                        let mut obj = SoftEdge::default();
+                        obj.set_attributes(reader, e);
+                        &mut self.set_soft_edge(obj);
                     }
+                    _ => (),
                 },
-                Ok(Event::Start(ref e)) => {
-                    match e.name() {
-                        b"a:glow" => {
-                            let mut obj = Glow::default();
-                            obj.set_attributes(reader, e);
-                            &mut self.set_glow(obj);
-                        },
-                        b"a:outerShdw" => {
-                            let mut obj = OuterShadow::default();
-                            obj.set_attributes(reader, e);
-                            &mut self.set_outer_shadow(obj);
-                        },
-                        _ => (),
+                Ok(Event::Start(ref e)) => match e.name() {
+                    b"a:glow" => {
+                        let mut obj = Glow::default();
+                        obj.set_attributes(reader, e);
+                        &mut self.set_glow(obj);
                     }
+                    b"a:outerShdw" => {
+                        let mut obj = OuterShadow::default();
+                        obj.set_attributes(reader, e);
+                        &mut self.set_outer_shadow(obj);
+                    }
+                    _ => (),
                 },
-                Ok(Event::End(ref e)) => {
-                    match e.name() {
-                        b"a:effectLst" => return,
-                        _ => (),
-                    }
+                Ok(Event::End(ref e)) => match e.name() {
+                    b"a:effectLst" => return,
+                    _ => (),
                 },
                 Ok(Event::Eof) => panic!("Error not find {} end element", "a:effectLst"),
                 Err(e) => panic!("Error at position {}: {:?}", reader.buffer_position(), e),
@@ -105,7 +99,8 @@ impl EffectList {
     }
 
     pub(crate) fn write_to(&self, writer: &mut Writer<Cursor<Vec<u8>>>) {
-        let empty_flag = self.glow.is_none() && self.outer_shadow.is_none() && self.soft_edge.is_none();
+        let empty_flag =
+            self.glow.is_none() && self.outer_shadow.is_none() && self.soft_edge.is_none();
 
         // a:effectLst
         write_start_tag(writer, "a:effectLst", vec![], empty_flag);
@@ -114,19 +109,19 @@ impl EffectList {
             // a:glow
             match &self.glow {
                 Some(v) => v.write_to(writer),
-                None => {},
+                None => {}
             }
 
             // a:outerShdow
             match &self.outer_shadow {
                 Some(v) => v.write_to(writer),
-                None => {},
+                None => {}
             }
 
             // a:softEdge
             match &self.soft_edge {
                 Some(v) => v.write_to(writer),
-                None => {},
+                None => {}
             }
 
             write_end_tag(writer, "a:effectLst");
