@@ -1,34 +1,36 @@
 // a:miter
 use super::super::super::Int32Value;
-use writer::driver::*;
-use reader::driver::*;
+use quick_xml::events::BytesStart;
 use quick_xml::Reader;
-use quick_xml::events::{BytesStart};
 use quick_xml::Writer;
+use reader::driver::*;
 use std::io::Cursor;
+use writer::driver::*;
 
 #[derive(Clone, Default, Debug)]
 pub struct Miter {
     limit: Int32Value,
 }
 impl Miter {
-    pub fn get_limit(&self)-> &i32 {
+    pub fn get_limit(&self) -> &i32 {
         &self.limit.get_value()
     }
-    
-    pub fn set_limit(&mut self, value:i32)-> &mut Self {
+
+    pub fn set_limit(&mut self, value: i32) -> &mut Self {
         self.limit.set_value(value);
         self
     }
 
     pub(crate) fn set_attributes<R: std::io::BufRead>(
         &mut self,
-        _reader:&mut Reader<R>,
-        e:&BytesStart
+        _reader: &mut Reader<R>,
+        e: &BytesStart,
     ) {
         match get_attribute(e, b"lim") {
-            Some(v) => {self.limit.set_value_string(v);},
-            None => {},
+            Some(v) => {
+                self.limit.set_value_string(v);
+            }
+            None => {}
         }
     }
 
