@@ -1,11 +1,11 @@
 // a:off
 use super::super::super::Int64Value;
-use writer::driver::*;
-use reader::driver::*;
+use quick_xml::events::BytesStart;
 use quick_xml::Reader;
-use quick_xml::events::{BytesStart};
 use quick_xml::Writer;
+use reader::driver::*;
 use std::io::Cursor;
+use writer::driver::*;
 
 #[derive(Clone, Default, Debug)]
 pub struct Offset {
@@ -17,7 +17,7 @@ impl Offset {
         &self.x.get_value()
     }
 
-    pub fn set_x(&mut self, value:i64) {
+    pub fn set_x(&mut self, value: i64) {
         self.x.set_value(value);
     }
 
@@ -25,14 +25,14 @@ impl Offset {
         &self.y.get_value()
     }
 
-    pub fn set_y(&mut self, value:i64) {
+    pub fn set_y(&mut self, value: i64) {
         self.y.set_value(value);
     }
-    
+
     pub(crate) fn set_attributes<R: std::io::BufRead>(
         &mut self,
-        _reader:&mut Reader<R>,
-        e:&BytesStart
+        _reader: &mut Reader<R>,
+        e: &BytesStart,
     ) {
         &mut self.x.set_value_string(get_attribute(e, b"x").unwrap());
         &mut self.y.set_value_string(get_attribute(e, b"y").unwrap());
@@ -40,9 +40,14 @@ impl Offset {
 
     pub(crate) fn write_to(&self, writer: &mut Writer<Cursor<Vec<u8>>>) {
         // a:off
-        write_start_tag(writer, "a:off", vec![
-            ("x",  &self.x.get_value_string()),
-            ("y",  &self.y.get_value_string()),
-        ], true);
+        write_start_tag(
+            writer,
+            "a:off",
+            vec![
+                ("x", &self.x.get_value_string()),
+                ("y", &self.y.get_value_string()),
+            ],
+            true,
+        );
     }
 }
