@@ -1,10 +1,10 @@
 // a:tailEnd
-use writer::driver::*;
-use reader::driver::*;
+use quick_xml::events::BytesStart;
 use quick_xml::Reader;
-use quick_xml::events::{BytesStart};
 use quick_xml::Writer;
+use reader::driver::*;
 use std::io::Cursor;
+use writer::driver::*;
 
 #[derive(Clone, Default, Debug)]
 pub struct TailEnd {
@@ -15,25 +15,25 @@ impl TailEnd {
         &self.r#type
     }
 
-    pub fn set_type<S: Into<String>>(&mut self, value:S) {
+    pub fn set_type<S: Into<String>>(&mut self, value: S) {
         self.r#type = value.into();
     }
 
     pub(crate) fn set_attributes<R: std::io::BufRead>(
         &mut self,
-        _reader:&mut Reader<R>,
-        e:&BytesStart
+        _reader: &mut Reader<R>,
+        e: &BytesStart,
     ) {
         match get_attribute(e, b"type") {
-            Some(v) => {&mut self.set_type(v);},
+            Some(v) => {
+                &mut self.set_type(v);
+            }
             None => {}
         }
     }
 
     pub(crate) fn write_to(&self, writer: &mut Writer<Cursor<Vec<u8>>>) {
         // a:tailEnd
-        write_start_tag(writer, "a:tailEnd", vec![
-            ("type", &self.r#type),
-        ], true);
+        write_start_tag(writer, "a:tailEnd", vec![("type", &self.r#type)], true);
     }
 }
