@@ -3,15 +3,14 @@ use quick_xml::Writer;
 use std::io;
 
 use super::driver::*;
-use super::XlsxError;
 use structs::Spreadsheet;
+use structs::WriterManager;
 
 pub(crate) fn write<W: io::Seek + io::Write>(
     spreadsheet: &Spreadsheet,
-    arv: &mut zip::ZipWriter<W>,
-    sub_dir: &str,
-    file_name: &str,
-) -> Result<(), XlsxError> {
+    has_shared_string_table: bool,
+    writer_mng: &mut WriterManager<W>,
+) {
     let mut writer = Writer::new(io::Cursor::new(Vec::new()));
     // XML header
     let _ = writer.write_event(Event::Decl(BytesDecl::new(
@@ -30,54 +29,59 @@ pub(crate) fn write<W: io::Seek + io::Write>(
     ));
     write_start_tag(&mut writer, root_tag_name, attributes, false);
 
+    let mut index = 1;
+
+    // relationships worksheet
+    for _ in spreadsheet.get_sheet_collection_no_check() {
+        let path_str = format!("worksheets/sheet{}.xml", index);
+        write_relationship(
+            &mut writer,
+            &index.to_string(),
+            "http://schemas.openxmlformats.org/officeDocument/2006/relationships/worksheet",
+            &path_str,
+            "",
+        );
+
+        index += 1;
+    }
+
     // relationship styles.xml
     write_relationship(
         &mut writer,
-        "1",
+        &index.to_string(),
         "http://schemas.openxmlformats.org/officeDocument/2006/relationships/styles",
         "styles.xml",
         "",
     );
+    index += 1;
 
     // relationship theme/theme1.xml
     write_relationship(
         &mut writer,
-        "2",
+        &index.to_string(),
         "http://schemas.openxmlformats.org/officeDocument/2006/relationships/theme",
         "theme/theme1.xml",
         "",
     );
+    index += 1;
 
     // relationship sharedStrings.xml
-    write_relationship(
-        &mut writer,
-        "3",
-        "http://schemas.openxmlformats.org/officeDocument/2006/relationships/sharedStrings",
-        "sharedStrings.xml",
-        "",
-    );
-
-    // relationships with sheets
-    let mut index = 0;
-    for i in 0..spreadsheet.get_sheet_count() {
-        index = i;
-        let id = (index + 1 + 3).to_string();
-        let p_target = format!("worksheets/sheet{}.xml", (index + 1).to_string().as_str());
+    if has_shared_string_table {
         write_relationship(
             &mut writer,
-            id.as_str(),
-            "http://schemas.openxmlformats.org/officeDocument/2006/relationships/worksheet",
-            p_target.as_str(),
+            &index.to_string(),
+            "http://schemas.openxmlformats.org/officeDocument/2006/relationships/sharedStrings",
+            "sharedStrings.xml",
             "",
         );
+        index += 1;
     }
 
     // relationships for vbaProject if needed
     if spreadsheet.get_has_macros() {
-        let id = (index + 1 + 3 + 1).to_string();
         write_relationship(
             &mut writer,
-            id.as_str(),
+            &index.to_string(),
             "http://schemas.microsoft.com/office/2006/relationships/vbaProject",
             "vbaProject.bin",
             "",
@@ -85,8 +89,13 @@ pub(crate) fn write<W: io::Seek + io::Write>(
     }
 
     write_end_tag(&mut writer, root_tag_name);
-    let _ = make_file_from_writer(&file_name, arv, writer, Some(sub_dir)).unwrap();
-    Ok(())
+    let _ = make_file_from_writer(
+        "xl/_rels/workbook.xml.rels",
+        writer_mng.get_arv_mut(),
+        writer,
+        None,
+    )
+    .unwrap();
 }
 
 fn write_relationship(
