@@ -3,23 +3,20 @@ use quick_xml::Writer;
 use std::io;
 
 use super::driver::*;
-use super::XlsxError;
 use structs::Worksheet;
-
-const SUB_DIR: &'static str = "xl/worksheets/_rels";
+use structs::WriterManager;
 
 pub(crate) fn write<W: io::Seek + io::Write>(
     worksheet: &Worksheet,
-    p_worksheet_id: &str,
-    drawing_id: &usize,
-    vml_drawing_id: &usize,
-    comment_id: &usize,
-    arv: &mut zip::ZipWriter<W>,
-    ole_bin_id: &usize,
-    ole_excel_id: &usize,
-    printer_settings_id: &usize,
-) -> Result<(), XlsxError> {
-    let file_name = format!("sheet{}.xml.rels", p_worksheet_id);
+    worksheet_no: &str,
+    drawing_no: &str,
+    vml_drawing_no: &str,
+    comment_no: &str,
+    ole_object_no_list: &Vec<String>,
+    excel_no_list: &Vec<String>,
+    printer_settings_no: &str,
+    writer_mng: &mut WriterManager<W>,
+) {
     let mut is_write = false;
 
     let mut writer = Writer::new(io::Cursor::new(Vec::new()));
@@ -60,7 +57,7 @@ pub(crate) fn write<W: io::Seek + io::Write>(
 
     // write pageSetup
     if worksheet.get_page_setup().get_object_data().is_some() {
-        let object_name = format!("printerSettings{}.bin", printer_settings_id);
+        let object_name = format!("printerSettings{}.bin", printer_settings_no);
         is_write = write_relationship(
             &mut writer,
             r_id.to_string().as_str(),
@@ -77,7 +74,7 @@ pub(crate) fn write<W: io::Seek + io::Write>(
             &mut writer,
             r_id.to_string().as_str(),
             "http://schemas.openxmlformats.org/officeDocument/2006/relationships/drawing",
-            format!("../drawings/drawing{}.xml", drawing_id.to_string().as_str()).as_str(),
+            format!("../drawings/drawing{}.xml", drawing_no.to_string().as_str()).as_str(),
             "",
         );
         r_id += 1;
@@ -91,7 +88,7 @@ pub(crate) fn write<W: io::Seek + io::Write>(
             "http://schemas.openxmlformats.org/officeDocument/2006/relationships/vmlDrawing",
             format!(
                 "../drawings/vmlDrawing{}.vml",
-                vml_drawing_id.to_string().as_str()
+                vml_drawing_no.to_string().as_str()
             )
             .as_str(),
             "",
@@ -100,11 +97,12 @@ pub(crate) fn write<W: io::Seek + io::Write>(
     }
 
     // Write ole_objects
-    let mut ole_excel_id = ole_excel_id.clone();
-    let mut ole_bin_id = ole_bin_id.clone();
+    let mut excel_no_list = excel_no_list.iter();
+    let mut ole_object_no_list = ole_object_no_list.iter();
     for ole_object in worksheet.get_ole_objects().get_ole_object() {
         if ole_object.is_xlsx() {
-            let object_name = format!("Microsoft_Excel_Worksheet{}.xlsx", ole_excel_id);
+            let excel_no = excel_no_list.next().unwrap();
+            let object_name = format!("Microsoft_Excel_Worksheet{}.xlsx", excel_no);
             write_relationship(
                 &mut writer,
                 r_id.to_string().as_str(),
@@ -112,11 +110,11 @@ pub(crate) fn write<W: io::Seek + io::Write>(
                 format!("../embeddings/{}", object_name).as_str(),
                 "",
             );
-            ole_excel_id += 1;
             r_id += 1;
         }
         if ole_object.is_bin() {
-            let object_name = format!("oleObject{}.bin", ole_bin_id);
+            let ole_object_no = ole_object_no_list.next().unwrap();
+            let object_name = format!("oleObject{}.bin", ole_object_no);
             write_relationship(
                 &mut writer,
                 r_id.to_string().as_str(),
@@ -124,7 +122,6 @@ pub(crate) fn write<W: io::Seek + io::Write>(
                 format!("../embeddings/{}", object_name).as_str(),
                 "",
             );
-            ole_bin_id += 1;
             r_id += 1;
         }
 
@@ -142,25 +139,13 @@ pub(crate) fn write<W: io::Seek + io::Write>(
         r_id += 1;
     }
 
-    // Write header/footer relationship
-    //let i = 1;
-    //if worksheet.get_header_footer().get_header_footer_images().len() > 0 {
-    //    is_write = write_relationship(
-    //        &mut writer,
-    //        format!("_headerfooter_vml{}", i.to_string().as_str()).as_str(),
-    //        "http://schemas.openxmlformats.org/officeDocument/2006/relationships/vmlDrawing",
-    //        format!("../drawings/vmlDrawingHF{}.xml", p_worksheet_id.to_string().as_str()).as_str(),
-    //        ""
-    //    );
-    //}
-
     // Write comments relationship
     if worksheet.get_comments().len() > 0 {
         is_write = write_relationship(
             &mut writer,
             r_id.to_string().as_str(),
             "http://schemas.openxmlformats.org/officeDocument/2006/relationships/comments",
-            format!("../comments{}.xml", comment_id.to_string().as_str()).as_str(),
+            format!("../comments{}.xml", comment_no.to_string().as_str()).as_str(),
             "",
         );
     }
@@ -168,9 +153,9 @@ pub(crate) fn write<W: io::Seek + io::Write>(
     write_end_tag(&mut writer, "Relationships");
 
     if is_write {
-        let _ = make_file_from_writer(&file_name, arv, writer, Some(SUB_DIR)).unwrap();
+        let file_path = format!("xl/worksheets/_rels/sheet{}.xml.rels", worksheet_no);
+        writer_mng.add_writer(&file_path, writer);
     }
-    Ok(())
 }
 
 fn write_relationship(
